#!/usr/bin/perl
#
# $Id: one_day_pat.pl,v 1.4 1998/06/22 18:28:56 wralph Exp $
#
#  Script to scan a tcpdump compressed hourly file using a pre-defined
#  tcpdump script. Parameters are: Date as YYMMDDHH and script name.
#  
#  Written by Bill Ralph 3/20/98
#
# Set up some variables.
#
use Getopt::Long;
use POSIX qw(strftime);
#
#  Catch user interrupt signal and abort the script.
#
sub sig_catch {
   my $signame = shift;
   die("Received SIG$signame.");
}
#
$SIG{INT}=\&sig_catch;
$CID_PATH = "/usr/local/logger";
$ENV{PATH} = "/bin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:$CID_PATH";
#
sub usage {
        print "Usage: one_day_pat.pl [-n] [-d DATE] [-l SITE] -p PATTERN.\n";
	exit 2;
}
#
#	Parse the parameters.
#
#
&GetOptions("n", \$no_lookup_flag, "d:s", \$snifdate, "l=s", \$Site,
            "p=s", \$pattern);
##
#
#  Check parameter validity.
#
if ("$Site" eq "" or $pattern eq "")
{
	usage();
}
#
# Once the Site is identified from the command line,
# load the needed external Parameters.
#
unshift(@INC, "$CID_PATH/sites");
die ("No such site: ${Site}.") if ( ! -e "$CID_PATH/sites/${Site}.ph");
require "${Site}.ph";

#
#
#
# If no snifdate specified on command line, assume today.
#
if ($snifdate eq "") {
   $snifdate = strftime("%y%m%d", localtime);
}
#
#  Break up the "snifdate" into its useful components.
#
$year=substr($snifdate,0,2);
$mon=substr($snifdate,2,2) - 1;
$mday=substr($snifdate,4,2);
$subdir=strftime("%h%d", 0, 0, 0, $mday, $mon, $year, 0, 0, 0);
#
#  Set the no_lookup_flag to -n for tcpdump if it was specified on the calling
#  parameter list.
#
$no_lookup_flag = ($no_lookup_flag eq "1") ?"-n":"";
#
# Ready to start the work now, find the hourly data files.
#
#print STDOUT ("${ANALYZER_DIR}/${subdir}\n");
#
# 
chdir("${ANALYZER_DIR}/${subdir}");
@files=<tcp.*.gz>;
$pattern='"'.$pattern.'"';
if ($files[0] eq "") {
#
#  No hourly files, they must have been already condensed into daily ones.
#
   @files=<day*.gz>;
}
foreach $file (@files) {
   $rc = 0xffff & system("gunzip -c $file | tcpdump $no_lookup_flag -r - $pattern 2>/dev/null");
   if (($rc > 0) && ($rc <= 0x80) && (($rc & ~0x80) != 0)) { exit 2; }
}
